#!/bin/bash

#
# Install script for "APLX for Linux" support libraries
#
# The support library files are required to run stand-alone applications
# (also called "packaged applications") created with APLX for Linux
#
# To install the files normally, run
#
#     install.sh
#
# If you would like to use a non-standard install path, give the path
# as an argument to this script, e.g.
#
#     install.sh /opt/mybin/
#
#
# Notes:
#
# The support libraries consist of three files
#     APLXSupport              [used for v3 APLX executables]
#     APLXSupport4             [used for v4 APLX executables]
#     libborqt-6.9.0-qt2.3.so
# which must be installed in the normal execution path (given by the $PATH
# environment variable)
#
# When these have been installed, a symbolic link called
# "libborqt-6.9-qt2.3.so" must be created, linked to "libborqt-6.9.0-qt2.3.so"
# e.g.
#      ln -sf libborqt-6.9.0-qt2.3.so libborqt-6.9-qt2.3.so
#
#

echo
echo "________________________________________________________________________________"
echo
echo "APLX for Linux Support Libraries"
echo "________________________________________________________________________________"
echo
echo

#
#  Choose an install path
#

# Given as command-line argument?
APLX_INST_DIR=$1
if [ -n "$APLX_INST_DIR" ]; then
	if [ ! -d $APLX_INST_DIR ]; then
		echo "\"$APLX_INST_DIR\" is not a directory"
		exit 1
	fi
	if [ ! -w $APLX_INST_DIR ]; then
		echo "Do not have write permission for \"$APLX_INST_DIR\""
		exit 1
	fi
fi

# or can we copy to /usr/local/bin? 
if [ -z "$APLX_INST_DIR" ]; then
	#echo "Trying /usr/local/bin"
	if [ -d "/usr/local/bin" ]; then
		if [ -w "/usr/local/bin" ]; then
			APLX_INST_DIR="/usr/local/bin"
		fi
	fi
fi

# or can we copy to /usr/bin?
if [ -z "$APLX_INST_DIR" ]; then
	#echo "Trying /usr/bin"
	if [ -d "/usr/bin" ]; then
		if [ -w "/usr/bin" ]; then
			APLX_INST_DIR="/usr/bin"
		fi
	fi
fi

# or can we copy to $HOME/bin?
if [ -z "$APLX_INST_DIR" ]; then
	#echo "Trying $HOME/bin"
	if [ -d "$HOME/bin" ]; then
		if [ -w "$HOME/bin" ]; then
			APLX_INST_DIR="$HOME/bin"
		fi
	fi
fi

# Didn't find anywhere? Prompt for an install directory
if [ -z "$APLX_INST_DIR" ]; then
	echo "The APLX for Linux support libraries should be installed to a directory which is"
	echo "in your normal executable search path when running stand-alone applications"
	echo "created with APLX for Linux."
	echo
	echo "Your current PATH is $PATH"
	echo
	echo "Please specify a directory where the APLX support libraries should be installed:"
	response=""
	while true; do
		echo
		echo -n "Please type a directory name, or <enter> to cancel: "
		read response
		if [ -z "$response" ]; then
			echo "Installation cancelled"
			echo
			exit 1
		fi
		if [ ! -d "$response" ]; then
			echo "\"$response\" is not a directory"
			continue
		fi
		if [ ! -w "$response" ]; then
			echo "You do not have write permission for \"$response\""
			echo "Contact your system administrator for assistance"
			continue
		fi

		# If we get here, he gave a writable directory name
		APLX_INST_DIR=$response
		break
	done
fi

# Display the install path and give a chance to cancel
echo
echo "Ready to install the APLX for Linux support libraries"
echo "Install path: \"$APLX_INST_DIR\""
while true; do
	echo
	echo -n "Install now? [y/n] "

	read response
	case $response in
	n|N|no|No|NO)
		echo "Installation cancelled"
		echo
		exit 1
		;;
	y|Y|yes|Yes|YES)
		break
		;;
	esac
done

# Now do the installation!

SRC_DIR=$(dirname $0)

echo
cp -f $SRC_DIR/APLXSupport $APLX_INST_DIR
if [ $? -ne 0 ]; then
	echo "Unable to copy APLXSupport"
	exit 1
fi

chmod 755 $APLX_INST_DIR/APLXSupport

cp -f $SRC_DIR/APLXSupport4 $APLX_INST_DIR
if [ $? -ne 0 ]; then
	echo "Unable to copy APLXSupport4"
	exit 1
fi

chmod 755 $APLX_INST_DIR/APLXSupport4

cp -f $SRC_DIR/libborqt-6.9.0-qt2.3.so $APLX_INST_DIR
if [ $? -ne 0 ]; then
	echo "Unable to copy libborqt"
	exit 1
fi

ln -sf $APLX_INST_DIR/libborqt-6.9.0-qt2.3.so $APLX_INST_DIR/libborqt-6.9-qt2.3.so
if [ $? -ne 0 ]; then
	echo "Unable to create link for libborqt"
	exit 1
fi


echo "Installation completed."
echo
echo "Ensure that \"$APLX_INST_DIR\" is in your search path when running "
echo "stand-alone applications created with APLX for Linux"
